/**
 * @file        ADSO-50216
 * @description Adjust forecasts - Multiply
 * @author      Clarence (ccn7@3ds.com)
 * @copyright   Dassault Systèmes
 */
import { AppMP, Demo, Scenario } from '../../libmp/appmp';
import { ListForecastsColumn, ListForecastsContextMenuItem } from '../../libmp/forms/form.forecasts';
import { DataMetalBaseSalesSegmentName } from '../../libmp/data/data.salessegment';
import { DataMetalBaseProductName } from '../../libmp/data/data.product';
import { DataMetalStockingPointName } from '../../libmp/data/data.stockingpoint';
import { StepList } from '../../libappsop/listsop';
import { StepActionBarPage } from '../../libappsop/actionbarpagesop';
import { DialogForecastAdjustQuantity } from '../../libmp/dialogs/dialog.forecastadjustquantity';
import { DataAdjustForecastQuantityMode } from '../../libmp/data/data.forecasts';
import { StepDialog } from '../../libappsop/dialogsop';
import { startOfPlanningYear } from '../../libmp/data/data.period';

describe('ADSO-50216 - Adjust forecasts - Multiply', () => {
  const appMP = AppMP.getInstance();
  const listForecasts = appMP.viewForecasts.formForecasts.listForecasts;
  const janSOP = `1-Jan-${startOfPlanningYear}`;
  const febSOP = `1-Feb-${startOfPlanningYear}`;
  const dlgAdjustQuantity: DialogForecastAdjustQuantity = new DialogForecastAdjustQuantity();
  const adjustRows: ListForecastsColumn[] = [{'Sales segment': DataMetalBaseSalesSegmentName.AllOrganics, Product: DataMetalBaseProductName.BCCBNarrow, 'Stocking point': DataMetalStockingPointName.NorthAmerica, Start: janSOP},
                                             {'Sales segment': DataMetalBaseSalesSegmentName.AllOrganics, Product: DataMetalBaseProductName.BCCBNarrow, 'Stocking point': DataMetalStockingPointName.NorthAmerica, Start: febSOP}];
  const adjustedRows: ListForecastsColumn[] = [{...adjustRows[0], 'Original Qty': '12,468'}, {...adjustRows[1], 'Original Qty': '13,473'}];
  const adjustedRows2: ListForecastsColumn[] = [{...adjustedRows[0], 'Original Qty': '6,234'}, {...adjustedRows[1], 'Original Qty': '6,736'}];

  beforeAll(async () => {
    await appMP.login();
  });

  afterAll(async () => {
    await appMP.resetActiveView(appMP.viewForecasts);
    await appMP.cleanupAndLogout();
  });

  afterEach(async () => {
    await appMP.checkToastMessage();
  });

  it(`Step 1 - ${AppMP.getDemoDataPath(Demo.Metals, Scenario.Base)}.`, async () => {
    await appMP.createDemoDataset(Demo.Metals, Scenario.Base, false);
  });

  it(`Step 2 - Open view ${appMP.viewForecasts.viewPath}.`, async () => {
    await appMP.viewForecasts.switchTo();
  });

  it(`Step 3 - ${StepList.selectRowsAndClickMenu(listForecasts.title, adjustRows, ListForecastsContextMenuItem.AdjustQuantity.Label)}`, async () => {
    const rows = await listForecasts.getRows(adjustRows);
    await listForecasts.selectRows(rows);
    await listForecasts.selectContextMenu(ListForecastsContextMenuItem.AdjustQuantity, rows, dlgAdjustQuantity);
  });

  it(`Step 4 - ${StepDialog.updateDialogValues(DialogForecastAdjustQuantity.title, {AdjustMode: DataAdjustForecastQuantityMode.Multiply})} ${StepDialog.verifyOKDisabled()}`, async () => {
    await dlgAdjustQuantity.updateDialogValues({AdjustMode: DataAdjustForecastQuantityMode.Multiply});
    await dlgAdjustQuantity.verifyOKDisabled();
  });

  it(`Step 5 - ${StepDialog.updateDialogValues(DialogForecastAdjustQuantity.title, {Value: '-2'})} ${StepDialog.verifyOKDisabled()}`, async () => {
    await dlgAdjustQuantity.updateDialogValues({Value: '-2'});
    await dlgAdjustQuantity.verifyOKDisabled();
  });

  it(`Step 6 - ${StepDialog.updateDialogValues(DialogForecastAdjustQuantity.title, {Value: '2.5'})} ${StepDialog.clickOK()}`, async () => {
    await dlgAdjustQuantity.updateDialogValues({Value: '2.5'});
    await dlgAdjustQuantity.clickOK();
  });

  it(`Step 7 - ${StepList.verifyRowExists(listForecasts.title, adjustedRows[0])} ${StepList.verifyRowExists(listForecasts.title, adjustedRows[1])}`, async () => {
    await listForecasts.verifyRowExists(adjustedRows[0]);
    await listForecasts.verifyRowExists(adjustedRows[1]);
  });

  it(`Step 8 - ${StepList.selectRows(listForecasts.title, adjustedRows)} ${StepActionBarPage.clickButton('Adjust quantity')}`, async () => {
    const rows = await listForecasts.getRows(adjustedRows);
    await listForecasts.selectRows(rows);
    await listForecasts.clickActionButton(appMP.abpSales.btnAdjustQuantity, undefined, rows, dlgAdjustQuantity);
  });

  it(`Step 9 - ${StepDialog.updateDialogValues(DialogForecastAdjustQuantity.title, {AdjustMode: DataAdjustForecastQuantityMode.Multiply, Value: '0.5'})} ${StepDialog.clickOK()}`, async () => {
    await dlgAdjustQuantity.updateDialogValues({AdjustMode: DataAdjustForecastQuantityMode.Multiply, Value: '0.5'});
    await dlgAdjustQuantity.clickOK();
  });

  it(`Step 10 - ${StepList.verifyRowExists(listForecasts.title, adjustedRows2[0])} ${StepList.verifyRowExists(listForecasts.title, adjustedRows2[1])}`, async () => {
    await listForecasts.verifyRowExists(adjustedRows2[0]);
    await listForecasts.verifyRowExists(adjustedRows2[1]);
  });
});
